==> tecfy_basic_package-0.1.14.tar.gz: lib/services/api.service.dart <==
part of tecfy_basic_package;

class ApiService {
  static String get token => ConfigService.token;

  static Future<OperationResult<Map>> httpGet(String url) async {
    try {
      var result = await httpGetString(url);
      if (!result.success)
        return OperationResult(success: false, message: result.message);
      var map = json.decode(result.data);
      print('$url: $map');
      return OperationResult(success: true, data: map);
    } catch (err) {
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpPost(String url, dynamic data,
      [bool asString = false]) async {
    try {
      HttpClient httpClient = new HttpClient();
      httpClient.connectionTimeout = Duration(seconds: 5);
      print('POST: ${await _getFullUrl(url)}');
      //print(data);
      HttpClientRequest request =
          await httpClient.postUrl(Uri.parse(await _getFullUrl(url)));
      request.headers.set('content-type', 'application/json');
      if (token != null && token.isNotEmpty)
        request.headers.set('Authorization', 'Bearer $token');

      if (asString) data = json.encode(data).replaceAll('\"', '\'');
      var body = json.encode(data);
      print(body);
      request.add(utf8.encode(body));
      HttpClientResponse response = await request.close();

      if (response.statusCode != 200) //&& response.statusCode !=307
      {
        print(response.statusCode);
        return OperationResult(
            success: false, message: 'Result code = ${response.statusCode}');
      }

      String reply = await response.transform(utf8.decoder).join();

      httpClient.close();

      var r = jsonDecode(reply);
      print(r);
      return OperationResult(
          success: r['success'],
          message: r['errorString'],
          data: r['data'],
          errorCodeString: r['errorCodeString']);
      // } else
      //   return OperationResult(success: false, message: 'Result code = ${result.statusCode}');
    } catch (err) {
      print('xxxxxxxxxxxx ERROR: POST');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpPut(String url, Map data) async {
    try {
      HttpClient httpClient = new HttpClient();
      httpClient.connectionTimeout = Duration(seconds: 5);
      print('PUT: ${await _getFullUrl(url)}');
      //print(data);
      HttpClientRequest request =
          await httpClient.putUrl(Uri.parse(await _getFullUrl(url)));
      request.headers.set('content-type', 'application/json');
      if (token != null && token.isNotEmpty)
        request.headers.set('Authorization', 'Bearer $token');

      request.add(utf8.encode(json.encode(data)));
      HttpClientResponse response = await request.close();

      if (response.statusCode != 200) //&& response.statusCode !=307
      {
        print(response.statusCode);
        return OperationResult(
            success: false, message: 'Result code = ${response.statusCode}');
      }

      String reply = await response.transform(utf8.decoder).join();

      httpClient.close();

      var r = jsonDecode(reply);
      print(r);
      return OperationResult(
        success: r['success'],
        message: r['errorString'],
        data: r['data'],
        errorCodeString: r['errorCodeString'],
      );
      // } else
      //   return OperationResult(success: false, message: 'Result code = ${result.statusCode}');
    } catch (err) {
      print('xxxxxxxxxxxx ERROR: POST');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpPostEx(String url, dynamic data,
      [bool addToken = true]) async {
    try {
      print('POST: ${await _getFullUrl(url)}');

      var result = await http.post(await _getFullUrl(url),
          body: json.encode(data),
          headers: addToken
              ? {
                  'content-type': 'application/json',
                  'Authorization': 'Bearer $token'
                }
              : {'content-type': 'application/json'});

      if (result.statusCode != 200) {
        print('XXXXXXX  Response status code ${result.statusCode}');
        return OperationResult(
            success: false, message: 'Result code = ${result.statusCode}');
      }

      String reply = result.body;
      var r = jsonDecode(reply);

      return OperationResult(
          success: r['success'] ?? false,
          message: r['errorString'] ??
              r['fullMessagesString'] ??
              r['errorCodeString'] ??
              'No Response',
          data: r['data'],
          errorCodeString: r['errorCodeString']);
    } catch (err) {
      print('xxxxxxxxxxxx ERROR: POST');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpPutEx(
      String url, dynamic data) async {
    try {
      print('PUT: ${await _getFullUrl(url)}');
      //print(data);

      var result = await http.put(await _getFullUrl(url),
          body: json.encode(data),
          headers: {
            'content-type': 'application/json',
            'Authorization': 'Bearer $token'
          });

      if (result.statusCode != 200) //&& response.statusCode !=307
      {
        print(result.statusCode);
        return OperationResult(
            success: false, message: 'Result code = ${result.statusCode}');
      }

      String reply = result.body;

      var r = jsonDecode(reply);
      print(r);
      return OperationResult(
          success: r['success'],
          message: r['errorString'],
          data: r['data'],
          errorCodeString: r['errorCodeString']);
      // } else
      //   return OperationResult(success: false, message: 'Result code = ${result.statusCode}');
    } catch (err) {
      print('xxxxxxxxxxxx ERROR: POST');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpGetDynamic(String url) async {
    try {
      print('GET --------------------- ${await _getFullUrl(url)}');

      var response = await http.get(await _getFullUrl(url), headers: {
        'content-type': 'application/json',
        'Authorization': 'Bearer $token'
      });
      if (response.statusCode != 200) {
        print('XXXXXXXXXXX GET status is ${response.statusCode} $url');
        return OperationResult(
            success: false, message: 'Result code = ${response.statusCode}');
      } else
        print('GET response $url');
      String reply = response.body;

      if (reply == null || reply.length == 0)
        return OperationResult(success: false, message: 'Result is empty');

      var r = jsonDecode(reply);

      if (r['success'] != true) print(r);
      // else
      //   print('Response success =true');
      return OperationResult(
        success: r['success'],
        message: r['errorString'] ??
            r['errorCodeString'] ??
            r['fullMessagesString'] ??
            'No Server Error!',
        data: r['data'],
      );
    } catch (err) {
      print('xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx ERROR: GET: $url');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpDeleteDynamic(String url) async {
    try {
      print('DELETE --------------------- ${await _getFullUrl(url)}');

      var response = await http.delete(await _getFullUrl(url), headers: {
        'content-type': 'application/json',
        'Authorization': 'Bearer $token'
      });

      if (response.statusCode != 200)
        return OperationResult(
            success: false, message: 'Result code = ${response.statusCode}');

      String reply = response.body;

      if (reply == null || reply.length == 0)
        return OperationResult(success: false, message: 'Result is empty');

      var r = jsonDecode(reply);

      if (r['success'] != true) print(r);
      return OperationResult(
        success: r['success'],
        message: r['errorString'] ??
            r['errorCodeString'] ??
            r['fullMessagesString'] ??
            'No Server Error!',
        data: r['data'],
      );
    } catch (err) {
      print('xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx   ERROR: DELETE: $url');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpDeleteDynamicEx(
      String url) async {
    try {
      print('DELETE --------------------- ${await _getFullUrl(url)}');

      HttpClient httpClient = new HttpClient();
      httpClient.connectionTimeout = Duration(seconds: 3);
      print('start create request');
      HttpClientRequest request =
          await httpClient.deleteUrl(Uri.parse(await _getFullUrl(url)));
      request.headers.set('content-type', 'application/json');
      request.headers.set('Authorization', 'Bearer $token');
      print('start send command');
      HttpClientResponse response = await request.close();

      if (response.statusCode != 200)
        return OperationResult(
            success: false, message: 'Result code = ${response.statusCode}');

      String reply = await response.transform(utf8.decoder).join();
      httpClient.close(force: true);

      if (reply == null || reply.length == 0)
        return OperationResult(success: false, message: 'Result is empty');

      var r = jsonDecode(reply);

      // try{
      //   print('******************************* Saving in cash for test porpuse   ::  ' + url);
      //   ConfigService.setMap(url,r);
      // } catch (err) {
      //   print('xxxxxxxxxxx-----------------xxxxxxxxxxxxxxx   Canot Set in cash .....: DELETE: $url');
      //   }
      if (r['success'] != true) print(r);
      return OperationResult(
        success: r['success'],
        message: r['errorString'] ??
            r['errorCodeString'] ??
            r['fullMessagesString'] ??
            'No Server Error!',
        data: r['data'],
      );
    } catch (err) {
      print('xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx   ERROR: DELETE: $url');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<String>> httpGetString(String url) async {
    try {
      var result = await http.get(await _getFullUrl(url));

      if (result.statusCode == 200) {
        return OperationResult(success: true, data: result.body);
      } else
        return OperationResult(
            success: false, message: 'Result code = ${result.statusCode}');
    } catch (err) {
      return OperationResult(success: false, message: err.toString());
    }
  }

  // static String apiURL = 'http://app.tecfy.co/api/';
  static String get apiURL => ConfigService.apiURL;
  static Future<String> _getFullUrl(String url) async {
    if (url.startsWith('http')) return url;
    while (apiURL == null || apiURL.isEmpty) {
      await Future.delayed(Duration(milliseconds: 100));
    }
    return "$apiURL$url";
  }

  static Future<OperationResult<String>> httpPostFile(
      String url, Uint8List fileData, String name,
      [bool isImage = true]) async {
    String dataString;
    try {
      //print('POST:---- ${_getFullUrl(url)}   $name');
      var request =
          http.MultipartRequest("POST", Uri.parse(await _getFullUrl(url)));

      request.headers['Authorization'] = 'Bearer $token';
      // request.fields['user'] = 'someone@somewhere.com';
      request.files.add(http.MultipartFile.fromBytes(
        'file',
        fileData,
        filename: name,
        contentType: isImage
            ? MediaType("image", path.extension(name))
            : MediaType('application', 'x-tar'),
      ));

      request.headers["Authorization"] = "Bearer $token";
      // request.headers["Accept"] = vimeoUploadHeader;
      request.headers["Content-Type"] = "image/jpg";
      //request.headers["Content-Length"] = fileData.length.toString();
      var response = await request.send();
      if (response.statusCode == 200) {
        print("Uploaded!!!");

        var data = (await response.stream.toBytes());
        // print(utf8.decode(data));
        print(data.length);
        dataString = utf8.decode(data);
        print(dataString);
        var r = json.decode(dataString);
        return OperationResult(
            success: r['success'],
            message: r['errorString'],
            data: r['data'],
            errorCodeString: r['errorCodeString']);
      }
      return OperationResult(
          success: false, message: 'Error: ${response.statusCode}');
    } catch (err) {
      print(dataString);
      print('XXXXXXXXXXXXXXXX post file error: $err');
      return OperationResult(success: false, message: err.toString());
    }
  }
}

==> tecfy_basic_package-0.1.16.tar.gz: lib/services/api.service.dart <==
part of tecfy_basic_package;

class ApiService {
  static String get token => ConfigService.token;

  static Future<OperationResult<Map>> httpGet(String url) async {
    try {
      var result = await httpGetString(url);
      if (!result.success)
        return OperationResult(success: false, message: result.message);
      var map = json.decode(result.data);
      print('$url: $map');
      return OperationResult(success: true, data: map);
    } catch (err) {
      return OperationResult(success: false, message: err.toString());
    }
  }

  static dynamic customEncode(dynamic item) {
    if (item is DateTime) {
      return intl.DateFormat("yyyy-MM-ddTHH:mm:ss").format(item);
    }
    return item;
  }

  static Future<OperationResult<dynamic>> httpPost(String url, dynamic data,
      [bool asString = false]) async {
    try {
      HttpClient httpClient = new HttpClient();
      httpClient.connectionTimeout = Duration(seconds: 5);
      print('POST: ${await _getFullUrl(url)}');
      //print(data);
      HttpClientRequest request =
          await httpClient.postUrl(Uri.parse(await _getFullUrl(url)));
      request.headers.set('content-type', 'application/json');
      if (token != null && token.isNotEmpty)
        request.headers.set('Authorization', 'Bearer $token');

      if (asString)
        data =
            json.encode(data, toEncodable: customEncode).replaceAll('\"', '\'');
      var body = json.encode(data, toEncodable: customEncode);
      print(body);
      request.add(utf8.encode(body));
      HttpClientResponse response = await request.close();

      if (response.statusCode != 200) //&& response.statusCode !=307
      {
        print(response.statusCode);
        return OperationResult(
            success: false, message: 'Result code = ${response.statusCode}');
      }

      String reply = await response.transform(utf8.decoder).join();

      httpClient.close();

      var r = jsonDecode(reply);
      print(r);
      return OperationResult(
          success: r['success'],
          message: r['errorString'],
          data: r['data'],
          errorCodeString: r['errorCodeString']);
      // } else
      //   return OperationResult(success: false, message: 'Result code = ${result.statusCode}');
    } catch (err) {
      print('xxxxxxxxxxxx ERROR: POST');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpPut(String url, Map data) async {
    try {
      HttpClient httpClient = new HttpClient();
      httpClient.connectionTimeout = Duration(seconds: 5);
      print('PUT: ${await _getFullUrl(url)}');
      //print(data);
      HttpClientRequest request =
          await httpClient.putUrl(Uri.parse(await _getFullUrl(url)));
      request.headers.set('content-type', 'application/json');
      if (token != null && token.isNotEmpty)
        request.headers.set('Authorization', 'Bearer $token');

      request.add(utf8.encode(json.encode(data, toEncodable: customEncode)));
      HttpClientResponse response = await request.close();

      if (response.statusCode != 200) //&& response.statusCode !=307
      {
        print(response.statusCode);
        return OperationResult(
            success: false, message: 'Result code = ${response.statusCode}');
      }

      String reply = await response.transform(utf8.decoder).join();

      httpClient.close();

      var r = jsonDecode(reply);
      print(r);
      return OperationResult(
        success: r['success'],
        message: r['errorString'],
        data: r['data'],
        errorCodeString: r['errorCodeString'],
      );
      // } else
      //   return OperationResult(success: false, message: 'Result code = ${result.statusCode}');
    } catch (err) {
      print('xxxxxxxxxxxx ERROR: POST');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpPostEx(String url, dynamic data,
      [bool addToken = true]) async {
    try {
      print('POST: ${await _getFullUrl(url)}');

      var result = await http.post(await _getFullUrl(url),
          body: json.encode(data, toEncodable: customEncode),
          headers: addToken
              ? {
                  'content-type': 'application/json',
                  'Authorization': 'Bearer $token'
                }
              : {'content-type': 'application/json'});

      if (result.statusCode != 200) {
        print('XXXXXXX  Response status code ${result.statusCode}');
        return OperationResult(
            success: false, message: 'Result code = ${result.statusCode}');
      }

      String reply = result.body;
      var r = jsonDecode(reply);

      return OperationResult(
          success: r['success'] ?? false,
          message: r['errorString'] ??
              r['fullMessagesString'] ??
              r['errorCodeString'] ??
              'No Response',
          data: r['data'],
          errorCodeString: r['errorCodeString']);
    } catch (err) {
      print('xxxxxxxxxxxx ERROR: POST');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpPutEx(
      String url, dynamic data) async {
    try {
      print('PUT: ${await _getFullUrl(url)}');
      //print(data);

      var result = await http.put(await _getFullUrl(url),
          body: json.encode(data, toEncodable: customEncode),
          headers: {
            'content-type': 'application/json',
            'Authorization': 'Bearer $token'
          });

      if (result.statusCode != 200) //&& response.statusCode !=307
      {
        print(result.statusCode);
        return OperationResult(
            success: false, message: 'Result code = ${result.statusCode}');
      }

      String reply = result.body;

      var r = jsonDecode(reply);
      print(r);
      return OperationResult(
          success: r['success'],
          message: r['errorString'],
          data: r['data'],
          errorCodeString: r['errorCodeString']);
      // } else
      //   return OperationResult(success: false, message: 'Result code = ${result.statusCode}');
    } catch (err) {
      print('xxxxxxxxxxxx ERROR: POST');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpGetDynamic(String url) async {
    try {
      print('GET --------------------- ${await _getFullUrl(url)}');

      var response = await http.get(await _getFullUrl(url), headers: {
        'content-type': 'application/json',
        'Authorization': 'Bearer $token'
      });
      if (response.statusCode != 200) {
        print('XXXXXXXXXXX GET status is ${response.statusCode} $url');
        return OperationResult(
            success: false, message: 'Result code = ${response.statusCode}');
      } else
        print('GET response $url');
      String reply = response.body;

      if (reply == null || reply.length == 0)
        return OperationResult(success: false, message: 'Result is empty');

      var r = jsonDecode(reply);

      if (r['success'] != true) print(r);
      // else
      //   print('Response success =true');
      return OperationResult(
        success: r['success'],
        message: r['errorString'] ??
            r['errorCodeString'] ??
            r['fullMessagesString'] ??
            'No Server Error!',
        data: r['data'],
      );
    } catch (err) {
      print('xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx ERROR: GET: $url');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpDeleteDynamic(String url) async {
    try {
      print('DELETE --------------------- ${await _getFullUrl(url)}');

      var response = await http.delete(await _getFullUrl(url), headers: {
        'content-type': 'application/json',
        'Authorization': 'Bearer $token'
      });

      if (response.statusCode != 200)
        return OperationResult(
            success: false, message: 'Result code = ${response.statusCode}');

      String reply = response.body;

      if (reply == null || reply.length == 0)
        return OperationResult(success: false, message: 'Result is empty');

      var r = jsonDecode(reply);

      if (r['success'] != true) print(r);
      return OperationResult(
        success: r['success'],
        message: r['errorString'] ??
            r['errorCodeString'] ??
            r['fullMessagesString'] ??
            'No Server Error!',
        data: r['data'],
      );
    } catch (err) {
      print('xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx   ERROR: DELETE: $url');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<dynamic>> httpDeleteDynamicEx(
      String url) async {
    try {
      print('DELETE --------------------- ${await _getFullUrl(url)}');

      HttpClient httpClient = new HttpClient();
      httpClient.connectionTimeout = Duration(seconds: 3);
      print('start create request');
      HttpClientRequest request =
          await httpClient.deleteUrl(Uri.parse(await _getFullUrl(url)));
      request.headers.set('content-type', 'application/json');
      request.headers.set('Authorization', 'Bearer $token');
      print('start send command');
      HttpClientResponse response = await request.close();

      if (response.statusCode != 200)
        return OperationResult(
            success: false, message: 'Result code = ${response.statusCode}');

      String reply = await response.transform(utf8.decoder).join();
      httpClient.close(force: true);

      if (reply == null || reply.length == 0)
        return OperationResult(success: false, message: 'Result is empty');

      var r = jsonDecode(reply);

      // try{
      //   print('******************************* Saving in cash for test porpuse   ::  ' + url);
      //   ConfigService.setMap(url,r);
      // } catch (err) {
      //   print('xxxxxxxxxxx-----------------xxxxxxxxxxxxxxx   Canot Set in cash .....: DELETE: $url');
      //   }
      if (r['success'] != true) print(r);
      return OperationResult(
        success: r['success'],
        message: r['errorString'] ??
            r['errorCodeString'] ??
            r['fullMessagesString'] ??
            'No Server Error!',
        data: r['data'],
      );
    } catch (err) {
      print('xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx   ERROR: DELETE: $url');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<String>> httpGetString(String url) async {
    try {
      var result = await http.get(await _getFullUrl(url));

      if (result.statusCode == 200) {
        return OperationResult(success: true, data: result.body);
      } else
        return OperationResult(
            success: false, message: 'Result code = ${result.statusCode}');
    } catch (err) {
      return OperationResult(success: false, message: err.toString());
    }
  }

  // static String apiURL = 'http://app.tecfy.co/api/';
  static String get apiURL => ConfigService.apiURL;
  static Future<String> _getFullUrl(String url) async {
    if (url.startsWith('http')) return url;
    while (apiURL == null || apiURL.isEmpty) {
      await Future.delayed(Duration(milliseconds: 100));
    }
    return "$apiURL$url";
  }

  static Future<OperationResult<String>> httpPostFile(
      String url, Uint8List fileData, String name,
      [bool isImage = true]) async {
    String dataString;
    try {
      //print('POST:---- ${_getFullUrl(url)}   $name');
      var request =
          http.MultipartRequest("POST", Uri.parse(await _getFullUrl(url)));

      request.headers['Authorization'] = 'Bearer $token';
      // request.fields['user'] = 'someone@somewhere.com';
      request.files.add(http.MultipartFile.fromBytes(
        'file',
        fileData,
        filename: name,
        contentType: isImage
            ? MediaType("image", path.extension(name))
            : MediaType('application', 'x-tar'),
      ));

      request.headers["Authorization"] = "Bearer $token";
      // request.headers["Accept"] = vimeoUploadHeader;
      request.headers["Content-Type"] = "image/jpg";
      //request.headers["Content-Length"] = fileData.length.toString();
      var response = await request.send();
      if (response.statusCode == 200) {
        print("Uploaded!!!");

        var data = (await response.stream.toBytes());
        // print(utf8.decode(data));
        print(data.length);
        dataString = utf8.decode(data);
        print(dataString);
        var r = json.decode(dataString);
        return OperationResult(
            success: r['success'],
            message: r['errorString'],
            data: r['data'],
            errorCodeString: r['errorCodeString']);
      }
      return OperationResult(
          success: false, message: 'Error: ${response.statusCode}');
    } catch (err) {
      print(dataString);
      print('XXXXXXXXXXXXXXXX post file error: $err');
      return OperationResult(success: false, message: err.toString());
    }
  }
}
